/***********************************************************************

 SV1Codec user interface routines
 (header file)

 This file is a part of SV1Codec.
 SV1Codec is Copyright (C) 2002 by Marcin Grzegorczyk.

 Permission is granted to copy and redistribute this file under the
 terms of the Open Source MIT License. For more information please refer
 to the file sv1codec.c or to the SV1Codec documentation.

***********************************************************************/

#ifndef SV1C_UI_H
#define SV1C_UI_H

#include "sv1codec.h"


enum eMessageOutputMode { MSG_MODE_STDMSG, MSG_MODE_STDOUT, MSG_MODE_STDERR };


PUBLIC_DECLARATION void UI_WriteError(const char *filename, const int err);
PUBLIC_DECLARATION void UI_SeekError(const char *filename, const int err);
PUBLIC_DECLARATION void UI_IOFail_DeletingFile(const char *filename);
PUBLIC_DECLARATION void UI_IOFail_DeleteFileResult(const Bool failed, const int err);
PUBLIC_DECLARATION void UI_SearchForGameMsg(const char *path);
PUBLIC_DECLARATION void UI_GameFoundMsg(const char *path);
PUBLIC_DECLARATION void UI_GameNotFoundMsg(void);
PUBLIC_DECLARATION void UI_InputFileMsg(const char *const filename);
PUBLIC_DECLARATION void UI_FileOpenOrCreateFailed(const Bool create, const int err);
PUBLIC_DECLARATION void UI_CannotGetFileSize(const int err);
PUBLIC_DECLARATION void UI_FileSizeMsg(const long size);
PUBLIC_DECLARATION void UI_FileTooBig(void);
PUBLIC_DECLARATION void UI_FileTooSmall(void);
PUBLIC_DECLARATION void UI_OutOfMemForFileBuf(void);
PUBLIC_DECLARATION void UI_LoadingMsg(void);
PUBLIC_DECLARATION void UI_ErrorReadingFile(const int err);
PUBLIC_DECLARATION void (*const UI_LoadedMsg)(void);
PUBLIC_DECLARATION void UI_FileTypeMsg(const struct sOpParameters *const opp, const Bool big);
PUBLIC_DECLARATION enum eSVVersion UI_SaveTypeNotRecognized(void);
PUBLIC_DECLARATION void (*const UI_OutOfMemForTitleBuf)(void);
PUBLIC_DECLARATION void UI_FileTreatedAsTitleDemoMsg(void);
PUBLIC_DECLARATION void UI_GameTitleMsg(const char *const title);
PUBLIC_DECLARATION void UI_ComputingChecksumMsg(void);
PUBLIC_DECLARATION void UI_ChecksumComputedMsg(const uint32_t cc, const uint32_t fc, const Bool adj);
PUBLIC_DECLARATION void UI_IsTTPlayableDemoSaveMsg(void);
PUBLIC_DECLARATION void UI_AppearsToBeTitleDemoMsg(void);
PUBLIC_DECLARATION void UI_FileChecksumBad(void);
PUBLIC_DECLARATION void UI_IgnoreErrorProceed(void);
PUBLIC_DECLARATION Bool UI_Abort_CanForceProceed(void);
PUBLIC_DECLARATION void UI_FileIsNotASavegameMsg(void);
PUBLIC_DECLARATION enum eSVVersion UI_BigSizeNotRecognized(void);
PUBLIC_DECLARATION void UI_TTDPatchSigBad(const signed char ttdp_sig, const int ttdp);
PUBLIC_DECLARATION void (*const UI_OutOfMemForBigNameBuf)(void);
PUBLIC_DECLARATION void UI_UnrecognizedOption(const char *s, const size_t l);
PUBLIC_DECLARATION void UI_MissingOptionArgument(const char *s, const size_t l);
PUBLIC_DECLARATION void UI_TooManyFilenames(void);
PUBLIC_DECLARATION void UI_OutputPathTooLong(void);
PUBLIC_DECLARATION void (*const UI_OutOfMemForOutFileName)(void);
PUBLIC_DECLARATION void UI_CannotDetectLandscapeStyle(const struct sOpParameters *const opp);
PUBLIC_DECLARATION void UI_BadLandscapeStyle(int style);
PUBLIC_DECLARATION int UI_LandscapeLetterNotKnown(void);
PUBLIC_DECLARATION void UI_LandscapeStyleDetectedMsg(int style);
PUBLIC_DECLARATION char *UI_NoFreeSaveName(struct sFilesInfo *const finfo);
PUBLIC_DECLARATION void UI_SavingAsMsg(const char *path);
PUBLIC_DECLARATION void UI_UpdatingFileMsg(const char *path);
PUBLIC_DECLARATION void UI_FileCloseFailed(const int err, const Bool out_msgflag, const Bool err_msgflag);
PUBLIC_DECLARATION void (*const UI_FileWrittenAndClosedMsg)(void);
PUBLIC_DECLARATION void UI_RLEDecodeErrorWarn(void);
PUBLIC_DECLARATION void UI_ChecksumAfterEncodeMsg(unsigned long file_checksum);
PUBLIC_DECLARATION int UI__Initialize(void);
PUBLIC_DECLARATION void UI__SetMessageMode(enum eMessageOutputMode mode);
PUBLIC_DECLARATION void UI_ProgramGreeting(void);
PUBLIC_DECLARATION void UI_ProgramHelp(Bool full_help);
PUBLIC_DECLARATION void UI_NoInputFile(void);
PUBLIC_DECLARATION void UI_GameRequiresMoreVehMsg(int ttdp);
PUBLIC_DECLARATION Bool UI_TitleChksumBad_AskFix(uint16_t ctc, uint16_t ftc);
PUBLIC_DECLARATION void UI_TitleChksumFixedMsg(void);
PUBLIC_DECLARATION void (*const UI_FileChksumRecomputedMsg)(void);
PUBLIC_DECLARATION void UI_FileChksumFixedMsg(void);
PUBLIC_DECLARATION void UI_FileChksumOKNoActionMsg(void);
PUBLIC_DECLARATION void UI_TryNoArgsForHelp(void);


#endif /* SV1C_UI_H */

